Welcome to AA Toolbox
=====================

Welcome to AA Toolbox's documentation.

The `anticipatory action <https://centre.humdata.org/anticipatory-action/>`_
(AA) toolbox is a Python package to support development of AA frameworks, by
simplifying the downloading and processing of commonly used datasets.

Get set up
and start downloading data using :doc:`quickstart`.
The rest of the documentation describes the different data sources and
functionalities in more detail, with a complete reference in
the :doc:`api` section.

User Guide
----------

The following links provide background information on the AA Toolbox,
how to get started,
and detailed guides on the individual data sources plus any
additional functionality.

.. toctree::
   :maxdepth: 2

   introduction
   quickstart
   config
   datasources

API Reference
-------------

Detailed information on specific classes, methods, and functions.

.. toctree::
   :maxdepth: 1

   api

Miscellaneous
-------------

Development guide, license, and changelog.

.. toctree::
   :maxdepth: 2

   contributing
   license
   changelog
